@@ -28,15 +28,16 @@ import org.apache.flink.kubernetes.operator.controller.FlinkDeploymentController
 import org.apache.flink.kubernetes.operator.controller.FlinkSessionJobController;
 import org.apache.flink.kubernetes.utils.Constants;
 
+import io.fabric8.kubernetes.api.model.HasMetadata;
 import io.fabric8.kubernetes.api.model.apps.Deployment;
-import io.javaoperatorsdk.operator.api.config.informer.InformerConfiguration;
+import io.fabric8.kubernetes.api.model.networking.v1.Ingress;
+import io.javaoperatorsdk.operator.api.config.informer.InformerEventSourceConfiguration;
 import io.javaoperatorsdk.operator.api.reconciler.EventSourceContext;
 import io.javaoperatorsdk.operator.processing.event.ResourceID;
 import io.javaoperatorsdk.operator.processing.event.source.EventSource;
 import io.javaoperatorsdk.operator.processing.event.source.PrimaryToSecondaryMapper;
 import io.javaoperatorsdk.operator.processing.event.source.SecondaryToPrimaryMapper;
 import io.javaoperatorsdk.operator.processing.event.source.informer.InformerEventSource;
-import io.javaoperatorsdk.operator.processing.event.source.informer.Mappers;
 
 import java.util.Collections;
 import java.util.List;
@@ -45,9 +46,13 @@ import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import static org.apache.flink.kubernetes.operator.utils.IngressUtils.ingressInNetworkingV1;
+
 /** Utility class to locate secondary resources. */
 public class EventSourceUtils {
 
+    public static final String LABEL_COMPONENT_INGRESS = "ingress";
+
     private static final String FLINK_DEPLOYMENT_IDX = FlinkDeploymentController.class.getName();
     private static final String FLINK_SESSIONJOB_IDX = FlinkSessionJobController.class.getName();
     private static final String FLINK_STATE_SNAPSHOT_IDX = FlinkStateSnapshot.class.getName();
@@ -63,7 +68,8 @@ public class EventSourceUtils {
         var labelSelector =
                 String.format("%s in (%s)", CrdConstants.LABEL_SNAPSHOT_TRIGGER_TYPE, labelFilters);
         var configuration =
-                InformerConfiguration.from(FlinkStateSnapshot.class, context)
+                InformerEventSourceConfiguration.from(
+                                FlinkStateSnapshot.class, context.getPrimaryResourceClass())
                         .withLabelSelector(labelSelector)
                         .withSecondaryToPrimaryMapper(
                                 snapshot -> {
@@ -76,8 +82,8 @@ public class EventSourceUtils {
                                                     snapshot.getSpec().getJobReference().getName(),
                                                     snapshot.getMetadata().getNamespace()));
                                 })
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
         return new InformerEventSource<>(configuration, context);
     }
@@ -92,11 +98,32 @@ public class EventSourceUtils {
                         .collect(Collectors.joining(","));
 
         var configuration =
-                InformerConfiguration.from(Deployment.class, context)
+                InformerEventSourceConfiguration.from(Deployment.class, FlinkDeployment.class)
                         .withLabelSelector(labelSelector)
-                        .withSecondaryToPrimaryMapper(Mappers.fromLabel(Constants.LABEL_APP_KEY))
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
+                        .build();
+
+        return new InformerEventSource<>(configuration, context);
+    }
+
+    public static InformerEventSource<?, FlinkDeployment> getIngressInformerEventSource(
+            EventSourceContext<FlinkDeployment> context) {
+        final String labelSelector =
+                Map.of(Constants.LABEL_COMPONENT_KEY, LABEL_COMPONENT_INGRESS).entrySet().stream()
+                        .map(Object::toString)
+                        .collect(Collectors.joining(","));
+
+        var ingressClass =
+                ingressInNetworkingV1(context.getClient())
+                        ? Ingress.class
+                        : io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress.class;
+
+        var configuration =
+                InformerEventSourceConfiguration.from(ingressClass, FlinkDeployment.class)
+                        .withLabelSelector(labelSelector)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
 
         return new InformerEventSource<>(configuration, context);
@@ -114,8 +141,8 @@ public class EventSourceUtils {
                                                 flinkDeployment.getMetadata().getName(),
                                                 flinkDeployment.getMetadata().getNamespace())));
 
-        InformerConfiguration<FlinkSessionJob> configuration =
-                InformerConfiguration.from(FlinkSessionJob.class, context)
+        var configuration =
+                InformerEventSourceConfiguration.from(FlinkSessionJob.class, FlinkDeployment.class)
                         .withSecondaryToPrimaryMapper(
                                 sessionJob ->
                                         context
@@ -132,8 +159,8 @@ public class EventSourceUtils {
                                                 .stream()
                                                 .map(ResourceID::fromResource)
                                                 .collect(Collectors.toSet()))
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
 
         return new InformerEventSource<>(configuration, context);
@@ -150,8 +177,8 @@ public class EventSourceUtils {
                                                 sessionJob.getSpec().getDeploymentName(),
                                                 sessionJob.getMetadata().getNamespace())));
 
-        InformerConfiguration<FlinkDeployment> configuration =
-                InformerConfiguration.from(FlinkDeployment.class, context)
+        var configuration =
+                InformerEventSourceConfiguration.from(FlinkDeployment.class, FlinkSessionJob.class)
                         .withSecondaryToPrimaryMapper(
                                 flinkDeployment ->
                                         context
@@ -179,8 +206,8 @@ public class EventSourceUtils {
                                                                 sessionJob
                                                                         .getMetadata()
                                                                         .getNamespace())))
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
         return new InformerEventSource<>(configuration, context);
     }
@@ -201,8 +228,9 @@ public class EventSourceUtils {
                                             savepoint.getMetadata().getNamespace()));
                         });
 
-        InformerConfiguration<FlinkSessionJob> configurationFlinkSessionJob =
-                InformerConfiguration.from(FlinkSessionJob.class, context)
+        var configurationFlinkSessionJob =
+                InformerEventSourceConfiguration.from(
+                                FlinkSessionJob.class, FlinkStateSnapshot.class)
                         .withSecondaryToPrimaryMapper(getSnapshotPrimaryMapper(context))
                         .withPrimaryToSecondaryMapper(
                                 (PrimaryToSecondaryMapper<FlinkStateSnapshot>)
@@ -218,14 +246,15 @@ public class EventSourceUtils {
                                                             .getSnapshotJobReferenceResourceId(
                                                                     snapshot));
                                         })
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
         var flinkSessionJobEventSource =
                 new InformerEventSource<>(configurationFlinkSessionJob, context);
 
-        InformerConfiguration<FlinkDeployment> configurationFlinkDeployment =
-                InformerConfiguration.from(FlinkDeployment.class, context)
+        var configurationFlinkDeployment =
+                InformerEventSourceConfiguration.from(
+                                FlinkDeployment.class, FlinkStateSnapshot.class)
                         .withSecondaryToPrimaryMapper(getSnapshotPrimaryMapper(context))
                         .withPrimaryToSecondaryMapper(
                                 (PrimaryToSecondaryMapper<FlinkStateSnapshot>)
@@ -258,8 +287,8 @@ public class EventSourceUtils {
                                                             .getSnapshotJobReferenceResourceId(
                                                                     snapshot));
                                         })
-                        .withNamespacesInheritedFromController(context)
-                        .followNamespaceChanges(true)
+                        .withNamespacesInheritedFromController()
+                        .withFollowControllerNamespacesChanges(true)
                         .build();
         var flinkDeploymentEventSource =
                 new InformerEventSource<>(configurationFlinkDeployment, context);
@@ -283,6 +312,26 @@ public class EventSourceUtils {
                         .collect(Collectors.toSet());
     }
 
+    public static <T extends HasMetadata> SecondaryToPrimaryMapper<T> fromLabel(String nameKey) {
+        return resource -> {
+            final var metadata = resource.getMetadata();
+            if (metadata == null) {
+                return Collections.emptySet();
+            } else {
+                final var map = metadata.getLabels();
+                if (map == null) {
+                    return Collections.emptySet();
+                }
+                var name = map.get(nameKey);
+                if (name == null) {
+                    return Collections.emptySet();
+                }
+                var namespace = resource.getMetadata().getNamespace();
+                return Set.of(new ResourceID(name, namespace));
+            }
+        };
+    }
+
     private static String indexKey(String name, String namespace) {
         return name + "#" + namespace;
     }
