@@ -42,13 +42,9 @@ import io.fabric8.kubernetes.api.model.Event;
 import io.javaoperatorsdk.operator.api.reconciler.Cleaner;
 import io.javaoperatorsdk.operator.api.reconciler.Context;
 import io.javaoperatorsdk.operator.api.reconciler.DeleteControl;
-import io.javaoperatorsdk.operator.api.reconciler.ErrorStatusHandler;
 import io.javaoperatorsdk.operator.api.reconciler.ErrorStatusUpdateControl;
-import io.javaoperatorsdk.operator.api.reconciler.EventSourceContext;
-import io.javaoperatorsdk.operator.api.reconciler.EventSourceInitializer;
 import io.javaoperatorsdk.operator.api.reconciler.UpdateControl;
 import io.javaoperatorsdk.operator.processing.event.ResourceID;
-import io.javaoperatorsdk.operator.processing.event.source.EventSource;
 import lombok.Getter;
 
 import java.util.HashMap;
@@ -59,8 +55,6 @@ import java.util.function.BiConsumer;
 /** A wrapper around {@link FlinkSessionJobController} used by unit tests. */
 public class TestingFlinkSessionJobController
         implements io.javaoperatorsdk.operator.api.reconciler.Reconciler<FlinkSessionJob>,
-                ErrorStatusHandler<FlinkSessionJob>,
-                EventSourceInitializer<FlinkSessionJob>,
                 Cleaner<FlinkSessionJob> {
 
     @Getter private CanaryResourceManager<FlinkSessionJob> canaryResourceManager;
@@ -154,12 +148,6 @@ public class TestingFlinkSessionJobController
         return flinkSessionJobController.cleanup(cloned, context);
     }
 
-    @Override
-    public Map<String, EventSource> prepareEventSources(
-            EventSourceContext<FlinkSessionJob> eventSourceContext) {
-        return null;
-    }
-
     public Queue<Event> events() {
         return flinkResourceEventCollector.events;
     }
